@@ -20,9 +20,7 @@
  * 	Copyright (C) 2004  Red Hat, Inc.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,8 +44,6 @@ typedef struct
   GtkWidget *menu_item;
 } SidebarPage;
 
-#define GDICT_SIDEBAR_GET_PRIVATE(obj)	(G_TYPE_INSTANCE_GET_PRIVATE ((obj), GDICT_TYPE_SIDEBAR, GdictSidebarPrivate))
-
 struct _GdictSidebarPrivate
 {
   GHashTable *pages_by_id;
@@ -72,9 +68,9 @@ enum
 static guint sidebar_signals[LAST_SIGNAL] = { 0 };
 static GQuark sidebar_page_id_quark = 0;
 
-G_DEFINE_TYPE (GdictSidebar, gdict_sidebar, GTK_TYPE_BOX);
+G_DEFINE_TYPE_WITH_PRIVATE (GdictSidebar, gdict_sidebar, GTK_TYPE_BOX)
 
-SidebarPage *
+static SidebarPage *
 sidebar_page_new (const gchar *id,
 		  const gchar *name,
 		  GtkWidget   *widget)
@@ -92,7 +88,7 @@ sidebar_page_new (const gchar *id,
   return page;
 }
 
-void
+static void
 sidebar_page_free (SidebarPage *page)
 {
   if (G_LIKELY (page))
@@ -300,8 +296,6 @@ gdict_sidebar_class_init (GdictSidebarClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (gobject_class, sizeof (GdictSidebarPrivate));
-  
   sidebar_page_id_quark = g_quark_from_static_string ("gdict-sidebar-page-id");
 
   gobject_class->finalize = gdict_sidebar_finalize;
@@ -335,7 +329,7 @@ gdict_sidebar_init (GdictSidebar *sidebar)
   GtkWidget *close_button;
   GtkWidget *arrow;
 
-  sidebar->priv = priv = GDICT_SIDEBAR_GET_PRIVATE (sidebar);
+  sidebar->priv = priv = gdict_sidebar_get_instance_private (sidebar);
 
   gtk_orientable_set_orientation (GTK_ORIENTABLE (sidebar),
                                   GTK_ORIENTATION_VERTICAL);
