@@ -84,14 +84,14 @@ enum
 static GParamSpec *gdict_window_properties[LAST_PROP] = { NULL, };
 static guint gdict_window_signals[LAST_SIGNAL] = { 0 };
 
-static const GtkTargetEntry drop_types[] =
+static GtkTargetEntry drop_types[] =
 {
-  { "text/plain",    0, 0 },
-  { "TEXT",          0, 0 },
-  { "STRING",        0, 0 },
-  { "UTF8_STRING",   0, 0 },
+  { (char *) "text/plain",    0, 0 },
+  { (char *) "TEXT",          0, 0 },
+  { (char *) "STRING",        0, 0 },
+  { (char *) "UTF8_STRING",   0, 0 },
 };
-static const guint n_drop_types = G_N_ELEMENTS (drop_types);
+static guint n_drop_types = G_N_ELEMENTS (drop_types);
 
 
 
@@ -302,7 +302,7 @@ gdict_window_error_cb (GdictContext *context,
   if (error->code == GDICT_CONTEXT_ERROR_NO_MATCH)
     {
       GdictSource *source;
-      GdictContext *context;
+      GdictContext *source_context;
 
       gdict_window_set_sidebar_visible (window, TRUE);
       gdict_sidebar_view_page (GDICT_SIDEBAR (window->sidebar),
@@ -314,18 +314,15 @@ gdict_window_error_cb (GdictContext *context,
        */
       source = gdict_source_loader_get_source (window->loader,
 		      			       window->source_name);
-      context = gdict_source_get_context (source);
+      source_context = gdict_source_get_context (source);
 
-      gdict_speller_set_context (GDICT_SPELLER (window->speller),
-		      		 context);
-      g_object_unref (context);
+      gdict_speller_set_context (GDICT_SPELLER (window->speller), source_context);
+      g_object_unref (source_context);
       g_object_unref (source);
       
-      gdict_speller_set_strategy (GDICT_SPELLER (window->speller),
-			          window->strategy);
+      gdict_speller_set_strategy (GDICT_SPELLER (window->speller), window->strategy);
       
-      gdict_speller_match (GDICT_SPELLER (window->speller),
-		           window->word);
+      gdict_speller_match (GDICT_SPELLER (window->speller), window->word);
     }
 
   /* unset the word and update the UI */
@@ -704,7 +701,7 @@ gdict_window_store_state (GdictWindow *window)
   g_key_file_set_integer (state_key, "WindowState", "Height", window->current_height);
   g_key_file_set_boolean (state_key, "WindowState", "IsMaximized", window->is_maximized);
   g_key_file_set_boolean (state_key, "WindowState", "SidebarVisible", window->sidebar_visible);
-  g_key_file_set_integer (state_key, "WindowState", "SidebarWidth", window->sidebar_width);
+  g_key_file_set_double (state_key, "WindowState", "SidebarWidthPercentage", window->sidebar_width_percentage);
 
   page_id = gdict_sidebar_current_page (GDICT_SIDEBAR (window->sidebar));
   if (page_id == NULL)
@@ -788,11 +785,11 @@ gdict_window_load_state (GdictWindow *window)
       window->sidebar_visible = FALSE;
     }
 
-  window->sidebar_width = g_key_file_get_integer (state_key, "WindowState", "SidebarWidth", &error);
+  window->sidebar_width_percentage = g_key_file_get_double (state_key, "WindowState", "SidebarWidthPercentage", &error);
   if (error != NULL)
     {
       g_clear_error (&error);
-      window->sidebar_width = -1;
+      window->sidebar_width_percentage = -1;
     }
 
   window->sidebar_page = g_key_file_get_string (state_key, "WindowState", "SidebarPage", &error);
@@ -1114,12 +1111,20 @@ gdict_window_state_event_cb (GtkWidget           *widget,
 			     gpointer             user_data)
 {
   GdictWindow *window = GDICT_WINDOW (widget);
-  
+
   if (event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED)
     window->is_maximized = TRUE;
   else
     window->is_maximized = FALSE;
-  
+
+  gtk_window_get_size (GTK_WINDOW (window),
+                       &window->current_width,
+                       &window->current_height);
+
+  /* Resize the panel as the window is minimised/maximised */
+  gtk_paned_set_position (GTK_PANED (window->main_pane),
+                          window->current_width * (1.0 - window->sidebar_width_percentage));
+
   return FALSE;
 }
 
@@ -1298,12 +1303,13 @@ gdict_window_size_allocate (GtkWidget     *widget,
   if (GTK_WIDGET_CLASS (gdict_window_parent_class)->size_allocate != NULL)
     GTK_WIDGET_CLASS (gdict_window_parent_class)->size_allocate (widget, allocation);
 
-  if (!window->is_maximized)
-    {
-      gtk_window_get_size (GTK_WINDOW (widget),
-                           &window->current_width,
-                           &window->current_height);
-    }
+  gtk_window_get_size (GTK_WINDOW (window),
+                       &window->current_width,
+                       &window->current_height);
+
+  /* Resize the panel as the window is resized */
+  int paned_pos = window->current_width * (1.0 - window->sidebar_width_percentage);
+  gtk_paned_set_position (GTK_PANED (window->main_pane), paned_pos);
 }
 
 static void
@@ -1312,14 +1318,16 @@ gdict_window_handle_notify_position_cb (GtkWidget  *widget,
 					gpointer    user_data)
 {
   GdictWindow *window = GDICT_WINDOW (user_data);
-  gint window_width, pos;
-  GtkAllocation allocation;
 
-  pos = gtk_paned_get_position (GTK_PANED (widget));
-  gtk_widget_get_allocation (GTK_WIDGET (window), &allocation);
-  window_width = allocation.width;
+  int pos = gtk_paned_get_position (GTK_PANED (window->main_pane));
 
-  window->sidebar_width = window_width - pos;
+  double new_sidebar_width_percentage = 1.0 - pos / (double) window->current_width;
+  double diff_sidebar_width_percentage = fabs (window->sidebar_width_percentage - new_sidebar_width_percentage);
+  if (pos < window->current_width && diff_sidebar_width_percentage > 1e-2)
+    window->sidebar_width_percentage = new_sidebar_width_percentage;
+
+  int new_pos = window->current_width * (1.0 - window->sidebar_width_percentage);
+  gtk_paned_set_position (GTK_PANED (window->main_pane), new_pos);
 }
 
 static void
@@ -1330,7 +1338,6 @@ gdict_window_constructed (GObject *gobject)
   GtkWidget *button;
   PangoFontDescription *font_desc;
   gchar *font_name;
-  GtkAllocation allocation;
   GMenu *menu;
   
   window = GDICT_WINDOW (gobject);
@@ -1340,6 +1347,10 @@ gdict_window_constructed (GObject *gobject)
   /* recover the state */
   gdict_window_load_state (window);
 
+  /* Set a default value for the sidebar width (percentage) */
+  if (window->sidebar_width_percentage <= 0)
+    window->sidebar_width_percentage = 0.3333;
+
   /* build menus */
   g_action_map_add_action_entries (G_ACTION_MAP (window),
                                    entries, G_N_ELEMENTS (entries),
@@ -1350,7 +1361,7 @@ gdict_window_constructed (GObject *gobject)
    * the constructed() vfunc, so we need to use the global singleton
    */
   app = g_application_get_default ();
-  menu = gtk_application_get_menu_by_id (GTK_APPLICATION (app), "popup");
+  menu = gtk_application_get_menu_by_id (GTK_APPLICATION (app), "primary-menu");
   button = gtk_menu_button_new ();
   gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (button), G_MENU_MODEL (menu));
   gtk_menu_button_set_direction (GTK_MENU_BUTTON (button), GTK_ARROW_NONE);
@@ -1496,7 +1507,7 @@ gdict_window_constructed (GObject *gobject)
     }
 
   pango_font_description_free (font_desc);
-  
+
   gtk_window_set_title (GTK_WINDOW (window), _("Dictionary"));
   gtk_window_set_default_size (GTK_WINDOW (window),
                                window->default_width,
@@ -1504,8 +1515,6 @@ gdict_window_constructed (GObject *gobject)
   if (window->is_maximized)
     gtk_window_maximize (GTK_WINDOW (window));
 
-  gtk_widget_get_allocation (GTK_WIDGET (window), &allocation);
-  gtk_paned_set_position (GTK_PANED (window->main_pane), allocation.width - window->sidebar_width);
   if (window->sidebar_page != NULL)
     gdict_sidebar_view_page (GDICT_SIDEBAR (window->sidebar), window->sidebar_page);
   else
@@ -1665,6 +1674,8 @@ gdict_window_init (GdictWindow *window)
 
   window->default_width = -1;
   window->default_height = -1;
+  window->current_width = -1;
+  window->current_height = -1;
   window->is_maximized = FALSE;
   window->sidebar_visible = FALSE;
   window->sidebar_page = NULL;
